<?xml version="1.0" encoding="UTF-8"?>
<tagger name="french">
<tagset>
  <def-label name="ACRONIMOM">
    <tags-item tags="n.acr.m.*"/>
  </def-label>
  <def-label name="ACRONIMOF">
    <tags-item tags="n.acr.f.*"/>
  </def-label>
  <def-label name="ACRONIMOMF">
    <tags-item tags="n.acr.mf.*"/>
  </def-label>
  <def-label name="NOMM">
    <tags-item tags="n.m.*"/>
  </def-label>
  <def-label name="NOMF">
    <tags-item tags="n.f.*"/>
  </def-label>
  <def-label name="NOMMF">
    <tags-item tags="n.mf.*"/>
  </def-label>
  <def-label name="INTNOM" closed="true">
    <tags-item tags="prn.itg.*"/>
  </def-label> 
  <def-label name="INTADV" closed="true">
    <tags-item tags="adv.itg"/>
  </def-label>
  <def-label name="PREADV" closed="true">
    <tags-item tags="preadv"/>
  </def-label>
  <def-label name="ADV">
    <tags-item tags="adv"/>
  </def-label>
  <def-label name="CNJSUBS" closed="true">
    <tags-item tags="cnjsub"/>
  </def-label>
  <def-label name="CNJCOORD" closed="true">
    <tags-item tags="cnjcoo"/>
  </def-label>
  <def-label name="CNJADV">
    <tags-item tags="cnjadv"/>
  </def-label>
 <def-label name="DETM" closed="true">
    <tags-item tags="det.*.m.*"/>
  </def-label>
  <def-label name="DETF" closed="true">
    <tags-item tags="det.*.f.*"/>
  </def-label>
  <def-label name="DETMF" closed="true">
    <tags-item tags="det.*.mf.*"/>
  </def-label>
  <def-label name="DETNT">
    <tags-item tags="detnt"/>
  </def-label>
   <def-label name="INTERJ">
    <tags-item tags="ij"/>
  </def-label> 
  <def-label name="ANTROPONIM">
    <tags-item tags="np.ant"/>
  </def-label>
  <def-label name="TOPONIM">
    <tags-item tags="np.loc"/>
  </def-label>
  <def-label name="NPALTRES">
    <tags-item tags="np.al"/>
  </def-label>
  <def-label name="NUM" closed="true">
    <tags-item tags="num.*"/>
    <tags-item tags="num"/>
  </def-label>
  <def-label name="PREDET" closed="true">
    <tags-item tags="predet.*"/>
  </def-label>
  <def-label name="PREP" closed="true">
    <tags-item tags="pr"/>
  </def-label>
  <def-label name="PRNTNNT" closed="true">
    <tags-item tags="prn.tn.nt"/>
  </def-label>
  <def-label name="PRNTN" closed="true">
    <tags-item tags="prn.tn.*"/>
  </def-label>
  <def-label name="PRNENCREF" closed="true">
    <tags-item tags="prn.enc.ref.*"/>
  </def-label>
  <def-label name="PRNPROREF" closed="true">
    <tags-item tags="prn.pro.ref.*"/>
  </def-label>
  <def-label name="PRNENC" closed="true">
    <tags-item tags="prn.enc.*"/>
  </def-label>
  <def-label name="PRNPRO" closed="true">
    <tags-item tags="prn.pro.*"/>
  </def-label>
  <def-label name="VLEXINF">
    <tags-item tags="vblex.inf"/>
  </def-label>
  <def-label name="VLEXGER">
    <tags-item tags="vblex.ger"/>
  </def-label>
  <def-label name="VLEXPPRES">
    <tags-item tags="vblex.ppres.*"/>
  </def-label>
  <def-label name="VLEXPARTPI">
    <tags-item tags="vblex.pp.*"/>
  </def-label>
  <def-label name="VLEXPFCI">
    <tags-item tags="vblex.pri.*"/>
    <tags-item tags="vblex.fti.*"/>
    <tags-item tags="vblex.cni.*"/>
  </def-label>
  <def-label name="VLEXIPI">
    <tags-item tags="vblex.pii.*"/>
    <tags-item tags="vblex.ifi.*"/>
  </def-label>
  <def-label name="VLEXSUBJ">
    <tags-item tags="vblex.prs.*"/>
    <tags-item tags="vblex.pis.*"/>
    <tags-item tags="vblex.fts.*"/>
  </def-label>
  <def-label name="VLEXIMP">
    <tags-item tags="vblex.imp.*"/>
  </def-label>
  <def-label name="VSERINF" closed="true">
    <tags-item tags="vbser.inf"/>
  </def-label>
  <def-label name="VSERGER" closed="true">
    <tags-item tags="vbser.ger"/>
  </def-label>
  <def-label name="VSERPPRES" closed="true">
    <tags-item tags="vbser.ppres.*"/>
  </def-label>
  <def-label name="VSERPARTPI" closed="true">
    <tags-item tags="vbser.pp.*"/>
  </def-label>
  <def-label name="VSERPFCI" closed="true">
    <tags-item tags="vbser.pri.*"/>
    <tags-item tags="vbser.fti.*"/>
    <tags-item tags="vbser.cni.*"/>
  </def-label>
  <def-label name="VSERIPI" closed="true">
    <tags-item tags="vbser.pii.*"/>
    <tags-item tags="vbser.ifi.*"/>
  </def-label>
  <def-label name="VSERSUBJ" closed="true">
    <tags-item tags="vbser.prs.*"/>
    <tags-item tags="vbser.pis.*"/>
    <tags-item tags="vbser.fts.*"/>
  </def-label>
  <def-label name="VSERIMP" closed="true">
    <tags-item tags="vbser.imp.*"/>
  </def-label>
  <def-label name="VHABERINF" closed="true">
    <tags-item tags="vbhaver.inf"/>
  </def-label>
  <def-label name="VHABERGER" closed="true">
    <tags-item tags="vbhaver.ger"/>
  </def-label>
  <def-label name="VHABERPPRES" closed="true">
    <tags-item tags="vbhaver.ppres.*"/>
  </def-label>
  <def-label name="VHABERPARTPI" closed="true">
    <tags-item tags="vbhaver.pp.*"/>
  </def-label>
  <def-label name="VHABERPFCI" closed="true">
    <tags-item tags="vbhaver.pri.*"/>
    <tags-item tags="vbhaver.fti.*"/>
    <tags-item tags="vbhaver.cni.*"/>
  </def-label>
  <def-label name="VHABERIPI" closed="true">
    <tags-item tags="vbhaver.pii.*"/>
    <tags-item tags="vbhaver.ifi.*"/>
  </def-label>
  <def-label name="VHABERSUBJ" closed="true">
    <tags-item tags="vbhaver.prs.*"/>
    <tags-item tags="vbhaver.pis.*"/>
    <tags-item tags="vbhaver.fts.*"/>
  </def-label>
  <def-label name="VMODALINF" closed="true">
    <tags-item tags="vbmod.inf"/>
  </def-label>
  <def-label name="VMODALGER" closed="true">
    <tags-item tags="vbmod.ger"/>
  </def-label>
  <def-label name="VMODALPPRES" closed="true">
    <tags-item tags="vbmod.ppres.*"/>
  </def-label>
  <def-label name="VMODALPARTPI" closed="true">
    <tags-item tags="vbmod.pp.*"/>
  </def-label>
  <def-label name="VMODALPFCI" closed="true">
    <tags-item tags="vbmod.pri.*"/>
    <tags-item tags="vbmod.fti.*"/>
    <tags-item tags="vbmod.cni.*"/>
  </def-label>
  <def-label name="VMODALIPI" closed="true">
    <tags-item tags="vbmod.pii.*"/>
    <tags-item tags="vbmod.ifi.*"/>
  </def-label>
  <def-label name="VMODALSUBJ" closed="true">
    <tags-item tags="vbmod.prs.*"/>
    <tags-item tags="vbmod.pis.*"/>
    <tags-item tags="vbmod.fts.*"/>
  </def-label>
  <def-label name="VMODALIMP" closed="true">
    <tags-item tags="vbmod.imp.*"/>
  </def-label> 
 <def-label name="ADJF">
   <tags-item tags="adj.f.*"/>
   <tags-item tags="adj.ind.f.*"/>
 </def-label>
 <def-label name="ADJM">
   <tags-item tags="adj.m.*"/>
   <tags-item tags="adj.ind.m.*"/>
  </def-label>
 <def-label name="ADJMF">
   <tags-item tags="adj.mf.*"/>
   <tags-item tags="adj.ind.mf.*"/>
  </def-label> 
 <def-label name="ADJINT" closed="true">
    <tags-item tags="adj.itg.*"/>
  </def-label>
 <def-label name="ADJPOS" closed="true">
    <tags-item tags="adj.pos.*"/>
  </def-label>
  <def-label name="RELADV" closed="true">
    <tags-item tags="rel.adv"/>
  </def-label>
  <def-label name="REL" closed="true">
    <tags-item tags="rel.*"/>
  </def-label>
  <def-mult name="PREPDET" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.m.sg"/>
    </sequence>
    <sequence>
      <label-item label="PREP"/>
      <tags-item tags="det.def.mf.pl"/>
    </sequence>
  </def-mult>
  <def-mult name="PREPREL" closed="true">
    <sequence>
      <label-item label="PREP"/>
      <label-item label="REL"/>
    </sequence>
  </def-mult>
  <def-mult name="IMPLEXPRNENC">
    <sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="PRNENC"/>
   </sequence>
  </def-mult>
  <def-mult name="IMPSERPRNENC" closed="true">
    <sequence>
      <label-item label="VSERIMP"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
  <def-mult name="IMPMODPRNENC" closed="true">
    <sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="PRNENC"/>
    </sequence>
  </def-mult>
</tagset>

  <forbid>
   <label-sequence>
      <label-item label="PREP"/>
      <label-item label="PREP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="PREPDET"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXPPRES"/>
    </label-sequence>
     <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VLEXINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERPPRES"/>
    </label-sequence>     
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VSERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERPPRES"/>
    </label-sequence>
     <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VHABERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="VMODALINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VLEXINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VSERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VHABERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="VMODALINF"/>
    </label-sequence>
   <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VLEXINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERPPRES"/>
    </label-sequence>
   <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VSERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VHABERINF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="VMODALINF"/>
    </label-sequence>
    
     <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNPROREF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNENCREF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNPROREF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNENCREF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNPROREF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNENCREF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="PRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="PRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNPRO"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="PRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="DETMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="DETMF"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VSERIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    
  <!--prova prohibició verb que no siga être o avoir + participi-->  
   <!-- <label-sequence>
      <label-item label="VLEXPFCI"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIPI"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXSUBJ"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VLEXIMP"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
     <label-sequence>
      <label-item label="VMODALPFCI"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIPI"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALSUBJ"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VMODALIMP"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence> -->
    
<!--prova prohibició de nom i adj + ger pq trie ppres-->   
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>   
    
      
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="VSERGER"/>
    </label-sequence>  
    <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>  
      <label-sequence>
      <label-item label="NOMM"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NOMMF"/>
      <label-item label="VMODALGER"/>
    </label-sequence> 
    
          
    <label-sequence>
      <label-item label="ADJM"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJF"/>
      <label-item label="VSERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJMF"/>
      <label-item label="VSERGER"/>
    </label-sequence>  
    <label-sequence>
      <label-item label="ADJM"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJMF"/>
      <label-item label="VHABERGER"/>
    </label-sequence>  
      <label-sequence>
      <label-item label="ADJM"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJF"/>
      <label-item label="VMODALGER"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ADJMF"/>
      <label-item label="VMODALGER"/>
    </label-sequence> 
    
 <!--prova prohibir preposició davant de participi de present--> 
  
      <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VLEXPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VSERPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VMODALPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="VHABERPPRES"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VLEXGER"/>
    </label-sequence>

  <!-- fi proves-->
  
   
    <label-sequence>
      <label-item label="DETM"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETF"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="DETMF"/>
      <label-item label="SENT"/>
    </label-sequence>   
    <label-sequence>
      <label-item label="PREP"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREDET"/>
      <label-item label="SENT"/>
    </label-sequence>
  <!--  <label-sequence>
      <label-item label="RELN"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="RELAA"/>
      <label-item label="SENT"/>
    </label-sequence> --> 
    <label-sequence>
      <label-item label="REL"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="RELADV"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJCOORD"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJSUBS"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJADV"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="PREPDET"/>
      <label-item label="SENT"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VSERIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="VMODALIMP"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPMODPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="IMPSERPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="ANTROPONIM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="TOPONIM"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="NPALTRES"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJADV"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="CNJSUBS"/>
      <label-item label="IMPLEXPRNENC"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VLEXSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VSERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VHABERPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VHABERIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VHABERSUBJ"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALPFCI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALIPI"/>
    </label-sequence>
    <label-sequence>
      <label-item label="IMPLEXPRNENC"/>
      <label-item label="VMODALSUBJ"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VSERIMP"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VMODALIMP"/>
    </label-sequence> 
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VSERPARTPI"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="VMODALPARTPI"/>
    </label-sequence>   
    
    <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VLEXIMP"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VSERIMP"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VMODALIMP"/>
    </label-sequence> 
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VLEXPARTPI"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VSERPARTPI"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="VMODALPARTPI"/>
    </label-sequence>   
    
    <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="DETM"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="DETF"/>
    </label-sequence>  
    <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="DETMF"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="DETM"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="DETF"/>
    </label-sequence> 
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="DETMF"/>
    </label-sequence> 
    
    <label-sequence>
      <label-item label="PRNPROREF"/>
      <label-item label="ADV"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="ADV"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="NOMM"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="NOMF"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="NOMMF"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="ACRONIMOM"/>
    </label-sequence>  
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="ACRONIMOF"/>
    </label-sequence>   
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="ACRONIMOMF"/>
    </label-sequence>    
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="ANTROPONIM"/>
    </label-sequence>    
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="TOPONIM"/>
    </label-sequence>    
     <label-sequence>
      <label-item label="PRNPRO"/>
      <label-item label="NPALTRES"/>
    </label-sequence> 
    
    <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="VMODALINF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="VLEXINF"/>
    </label-sequence>
     <label-sequence>
      <label-item label="PRNTN"/>
      <label-item label="VSERINF"/>
    </label-sequence>
 
 
 <!--prova 29-05-07-->   
     <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="NOMM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="NOMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="NOMMF"/>
    </label-sequence>
    
        
     <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERINF"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPARTPI"/>
      <label-item label="ADJMF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="ADJM"/>
    </label-sequence> 
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="ADJF"/>
    </label-sequence>
    <label-sequence>
      <label-item label="VHABERPPRES"/>
      <label-item label="ADJMF"/>
    </label-sequence>
      
     <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="NUM"/>
    </label-sequence> 

  <!--  <label-sequence>
      <label-item label="VHABERPFCI"/>
      <label-item label="ADV"/>
    </label-sequence>
    
    <label-sequence>
      <label-item label="VHABERIPI"/>
      <label-item label="ADV"/>
    </label-sequence> 

    <label-sequence>
      <label-item label="VHABERGER"/>
      <label-item label="ADV"/>
    </label-sequence>

    <label-sequence>
      <label-item label="VHABERSUBJ"/>
      <label-item label="ADV"/>
    </label-sequence>  -->
   
  </forbid>

<!--
  <enforce-rules>
    <enforce-after label="PRNPROREF">
      <label-set>
        <label-item label="VLEXPFCI"/>
        <label-item label="VLEXIPI"/>
        <label-item label="VLEXSUBJ"/>
        <label-item label="VSERPFCI"/>
        <label-item label="VSERIPI"/>
        <label-item label="VSERSUBJ"/>
        <label-item label="VHABERPFCI"/>
        <label-item label="VHABERIPI"/>
        <label-item label="VHABERSUBJ"/>
        <label-item label="VMODALPFCI"/>
        <label-item label="VMODALIPI"/>
        <label-item label="VMODALSUBJ"/>
        <label-item label="VHABERPPRES"/>
        <label-item label="VLEXPPRES"/>
        <label-item label="VSERPPRES"/>
        <label-item label="VMODALPPRES"/>
      </label-set>
      </enforce-after>
       <enforce-after label="PRNPRO">
      <label-set>
        <label-item label="VLEXPFCI"/>
        <label-item label="VLEXIPI"/>
	<label-item label="VLEXINF"/>
	<label-item label="VLEXGER"/>
	<label-item label="VLEXPPRES"/>
        <label-item label="VLEXSUBJ"/>
        <label-item label="VSERPFCI"/>
        <label-item label="VSERIPI"/>
        <label-item label="VSERSUBJ"/>        
	<label-item label="VSERINF"/>
        <label-item label="VSERGER"/>
	<label-item label="VSERPPRES"/>
        <label-item label="VHABERPFCI"/>
        <label-item label="VHABERIPI"/>
        <label-item label="VHABERSUBJ"/>        
	<label-item label="VHABERINF"/>
        <label-item label="VHABERGER"/>
	<label-item label="VHABERPPRES"/>
        <label-item label="VMODALPFCI"/>
        <label-item label="VMODALIPI"/>
        <label-item label="VMODALSUBJ"/>  
	<label-item label="VMODALINF"/>
        <label-item label="VMODALGER"/>
	<label-item label="VMODALPPRES"/>
      </label-set>
    </enforce-after>
   <enforce-after label="PRNTN">
      <label-set>
        <label-item label="PRNPRO"/>
      </label-set>
   </enforce-after>
  </enforce-rules>-->
  

 <!-- <preferences>
   <prefer tags="vblex.pri.p3.sg"/>
   <prefer tags="vbser.pri.p3.sg"/>
   <prefer tags="vbhaver.pri.p3.sg"/>
   <prefer tags="vbmod.pri.p3.sg"/>  
   <prefer tags="vblex.pii.p3.sg"/>
   <prefer tags="vbser.pii.p3.sg"/>
   <prefer tags="vbhaver.pii.p3.sg"/>
   <prefer tags="vbmod.pii.p3.sg"/>
   <prefer tags="vblex.prs.p3.sg"/>
   <prefer tags="vbser.prs.p3.sg"/>
   <prefer tags="vbhaver.prs.p3.sg"/>
   <prefer tags="vbmod.prs.p3.sg"/>
   <prefer tags="vblex.cni.p3.sg"/>
   <prefer tags="vbser.cni.p3.sg"/>
   <prefer tags="vbhaver.cni.p3.sg"/>
   <prefer tags="vbmod.cni.p3.sg"/>
   <prefer tags="vblex.pis.p3.sg"/>
   <prefer tags="vbser.pis.p3.sg"/>
   <prefer tags="vbhaver.pis.p3.sg"/>
   <prefer tags="vbmod.pis.p3.sg"/>
  </preferences> -->
  
</tagger>
